Wrappers of common R Hessian functions.
Their purpose is to be passed as the hessian_function argument in the gas() function.
wrapper_hessian_stats(obj_fun, theta_optim, est_details, ...)wrapper_hessian_pracma(obj_fun, theta_optim, est_details, ...)
wrapper_hessian_numderiv(obj_fun, theta_optim, est_details, ...)
A list with components:
The status of the Hessian computation.
The Hessian matrix.
An objective function.
A numeric vector of the optimal values of the variables.
A list of variables used for estimation.
Additional arguments to be passed to the Hessian function.
wrapper_hessian_stats(): Wrapper for Hessian function stats::optimHess().
wrapper_hessian_pracma(): Wrapper for Hessian function pracma::hessian().
wrapper_hessian_numderiv(): Wrapper for Hessian function numDeriv::hessian().
gas()
wrappers_optim
wrappers_parallel